==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/entity/Office365GroupsActivityGroupCounts.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.time.LocalDate;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "reportRefreshDate", 
    "total", 
    "active", 
    "reportDate", 
    "reportPeriod"})
@JsonInclude(Include.NON_NULL)
public class Office365GroupsActivityGroupCounts extends Entity implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.office365GroupsActivityGroupCounts";
    }

    @JsonProperty("reportRefreshDate")
    protected LocalDate reportRefreshDate;

    @JsonProperty("total")
    protected Long total;

    @JsonProperty("active")
    protected Long active;

    @JsonProperty("reportDate")
    protected LocalDate reportDate;

    @JsonProperty("reportPeriod")
    protected String reportPeriod;

    protected Office365GroupsActivityGroupCounts() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderOffice365GroupsActivityGroupCounts() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private LocalDate reportRefreshDate;
        private Long total;
        private Long active;
        private LocalDate reportDate;
        private String reportPeriod;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder reportRefreshDate(LocalDate reportRefreshDate) {
            this.reportRefreshDate = reportRefreshDate;
            this.changedFields = changedFields.add("reportRefreshDate");
            return this;
        }

        public Builder total(Long total) {
            this.total = total;
            this.changedFields = changedFields.add("total");
            return this;
        }

        public Builder active(Long active) {
            this.active = active;
            this.changedFields = changedFields.add("active");
            return this;
        }

        public Builder reportDate(LocalDate reportDate) {
            this.reportDate = reportDate;
            this.changedFields = changedFields.add("reportDate");
            return this;
        }

        public Builder reportPeriod(String reportPeriod) {
            this.reportPeriod = reportPeriod;
            this.changedFields = changedFields.add("reportPeriod");
            return this;
        }

        public Office365GroupsActivityGroupCounts build() {
            Office365GroupsActivityGroupCounts _x = new Office365GroupsActivityGroupCounts();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.office365GroupsActivityGroupCounts";
            _x.id = id;
            _x.reportRefreshDate = reportRefreshDate;
            _x.total = total;
            _x.active = active;
            _x.reportDate = reportDate;
            _x.reportPeriod = reportPeriod;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id.toString()));
        }
    }

    @Property(name="reportRefreshDate")
    @JsonIgnore
    public Optional<LocalDate> getReportRefreshDate() {
        return Optional.ofNullable(reportRefreshDate);
    }

    public Office365GroupsActivityGroupCounts withReportRefreshDate(LocalDate reportRefreshDate) {
        Office365GroupsActivityGroupCounts _x = _copy();
        _x.changedFields = changedFields.add("reportRefreshDate");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.office365GroupsActivityGroupCounts");
        _x.reportRefreshDate = reportRefreshDate;
        return _x;
    }

    @Property(name="total")
    @JsonIgnore
    public Optional<Long> getTotal() {
        return Optional.ofNullable(total);
    }

    public Office365GroupsActivityGroupCounts withTotal(Long total) {
        Office365GroupsActivityGroupCounts _x = _copy();
        _x.changedFields = changedFields.add("total");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.office365GroupsActivityGroupCounts");
        _x.total = total;
        return _x;
    }

    @Property(name="active")
    @JsonIgnore
    public Optional<Long> getActive() {
        return Optional.ofNullable(active);
    }

    public Office365GroupsActivityGroupCounts withActive(Long active) {
        Office365GroupsActivityGroupCounts _x = _copy();
        _x.changedFields = changedFields.add("active");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.office365GroupsActivityGroupCounts");
        _x.active = active;
        return _x;
    }

    @Property(name="reportDate")
    @JsonIgnore
    public Optional<LocalDate> getReportDate() {
        return Optional.ofNullable(reportDate);
    }

    public Office365GroupsActivityGroupCounts withReportDate(LocalDate reportDate) {
        Office365GroupsActivityGroupCounts _x = _copy();
        _x.changedFields = changedFields.add("reportDate");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.office365GroupsActivityGroupCounts");
        _x.reportDate = reportDate;
        return _x;
    }

    @Property(name="reportPeriod")
    @JsonIgnore
    public Optional<String> getReportPeriod() {
        return Optional.ofNullable(reportPeriod);
    }

    public Office365GroupsActivityGroupCounts withReportPeriod(String reportPeriod) {
        Office365GroupsActivityGroupCounts _x = _copy();
        _x.changedFields = changedFields.add("reportPeriod");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.office365GroupsActivityGroupCounts");
        _x.reportPeriod = reportPeriod;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public Office365GroupsActivityGroupCounts patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        Office365GroupsActivityGroupCounts _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public Office365GroupsActivityGroupCounts put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        Office365GroupsActivityGroupCounts _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private Office365GroupsActivityGroupCounts _copy() {
        Office365GroupsActivityGroupCounts _x = new Office365GroupsActivityGroupCounts();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.id = id;
        _x.reportRefreshDate = reportRefreshDate;
        _x.total = total;
        _x.active = active;
        _x.reportDate = reportDate;
        _x.reportPeriod = reportPeriod;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("Office365GroupsActivityGroupCounts[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("reportRefreshDate=");
        b.append(this.reportRefreshDate);
        b.append(", ");
        b.append("total=");
        b.append(this.total);
        b.append(", ");
        b.append("active=");
        b.append(this.active);
        b.append(", ");
        b.append("reportDate=");
        b.append(this.reportDate);
        b.append(", ");
        b.append("reportPeriod=");
        b.append(this.reportPeriod);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}

==> odata-client-msgraph-beta-0.2.1-sources.jar: odata/msgraph/client/beta/entity/Office365GroupsActivityGroupCounts.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Long;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.time.LocalDate;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "active", 
    "reportDate", 
    "reportPeriod", 
    "reportRefreshDate", 
    "total"})
@JsonInclude(Include.NON_NULL)
public class Office365GroupsActivityGroupCounts extends Entity implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.office365GroupsActivityGroupCounts";
    }

    @JsonProperty("active")
    protected Long active;

    @JsonProperty("reportDate")
    protected LocalDate reportDate;

    @JsonProperty("reportPeriod")
    protected String reportPeriod;

    @JsonProperty("reportRefreshDate")
    protected LocalDate reportRefreshDate;

    @JsonProperty("total")
    protected Long total;

    protected Office365GroupsActivityGroupCounts() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderOffice365GroupsActivityGroupCounts() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private Long active;
        private LocalDate reportDate;
        private String reportPeriod;
        private LocalDate reportRefreshDate;
        private Long total;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder active(Long active) {
            this.active = active;
            this.changedFields = changedFields.add("active");
            return this;
        }

        public Builder reportDate(LocalDate reportDate) {
            this.reportDate = reportDate;
            this.changedFields = changedFields.add("reportDate");
            return this;
        }

        public Builder reportPeriod(String reportPeriod) {
            this.reportPeriod = reportPeriod;
            this.changedFields = changedFields.add("reportPeriod");
            return this;
        }

        public Builder reportRefreshDate(LocalDate reportRefreshDate) {
            this.reportRefreshDate = reportRefreshDate;
            this.changedFields = changedFields.add("reportRefreshDate");
            return this;
        }

        public Builder total(Long total) {
            this.total = total;
            this.changedFields = changedFields.add("total");
            return this;
        }

        public Office365GroupsActivityGroupCounts build() {
            Office365GroupsActivityGroupCounts _x = new Office365GroupsActivityGroupCounts();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.office365GroupsActivityGroupCounts";
            _x.id = id;
            _x.active = active;
            _x.reportDate = reportDate;
            _x.reportPeriod = reportPeriod;
            _x.reportRefreshDate = reportRefreshDate;
            _x.total = total;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id, String.class));
        }
    }

    @Property(name="active")
    @JsonIgnore
    public Optional<Long> getActive() {
        return Optional.ofNullable(active);
    }

    public Office365GroupsActivityGroupCounts withActive(Long active) {
        Office365GroupsActivityGroupCounts _x = _copy();
        _x.changedFields = changedFields.add("active");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.office365GroupsActivityGroupCounts");
        _x.active = active;
        return _x;
    }

    @Property(name="reportDate")
    @JsonIgnore
    public Optional<LocalDate> getReportDate() {
        return Optional.ofNullable(reportDate);
    }

    public Office365GroupsActivityGroupCounts withReportDate(LocalDate reportDate) {
        Office365GroupsActivityGroupCounts _x = _copy();
        _x.changedFields = changedFields.add("reportDate");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.office365GroupsActivityGroupCounts");
        _x.reportDate = reportDate;
        return _x;
    }

    @Property(name="reportPeriod")
    @JsonIgnore
    public Optional<String> getReportPeriod() {
        return Optional.ofNullable(reportPeriod);
    }

    public Office365GroupsActivityGroupCounts withReportPeriod(String reportPeriod) {
        Office365GroupsActivityGroupCounts _x = _copy();
        _x.changedFields = changedFields.add("reportPeriod");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.office365GroupsActivityGroupCounts");
        _x.reportPeriod = reportPeriod;
        return _x;
    }

    @Property(name="reportRefreshDate")
    @JsonIgnore
    public Optional<LocalDate> getReportRefreshDate() {
        return Optional.ofNullable(reportRefreshDate);
    }

    public Office365GroupsActivityGroupCounts withReportRefreshDate(LocalDate reportRefreshDate) {
        Office365GroupsActivityGroupCounts _x = _copy();
        _x.changedFields = changedFields.add("reportRefreshDate");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.office365GroupsActivityGroupCounts");
        _x.reportRefreshDate = reportRefreshDate;
        return _x;
    }

    @Property(name="total")
    @JsonIgnore
    public Optional<Long> getTotal() {
        return Optional.ofNullable(total);
    }

    public Office365GroupsActivityGroupCounts withTotal(Long total) {
        Office365GroupsActivityGroupCounts _x = _copy();
        _x.changedFields = changedFields.add("total");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.office365GroupsActivityGroupCounts");
        _x.total = total;
        return _x;
    }

    public Office365GroupsActivityGroupCounts withUnmappedField(String name, Object value) {
        Office365GroupsActivityGroupCounts _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public Office365GroupsActivityGroupCounts patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        Office365GroupsActivityGroupCounts _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public Office365GroupsActivityGroupCounts put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        Office365GroupsActivityGroupCounts _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private Office365GroupsActivityGroupCounts _copy() {
        Office365GroupsActivityGroupCounts _x = new Office365GroupsActivityGroupCounts();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.id = id;
        _x.active = active;
        _x.reportDate = reportDate;
        _x.reportPeriod = reportPeriod;
        _x.reportRefreshDate = reportRefreshDate;
        _x.total = total;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("Office365GroupsActivityGroupCounts[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("active=");
        b.append(this.active);
        b.append(", ");
        b.append("reportDate=");
        b.append(this.reportDate);
        b.append(", ");
        b.append("reportPeriod=");
        b.append(this.reportPeriod);
        b.append(", ");
        b.append("reportRefreshDate=");
        b.append(this.reportRefreshDate);
        b.append(", ");
        b.append("total=");
        b.append(this.total);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}
